@@ -6,7 +6,7 @@ use Mojo::Util 'monkey_patch';
 use JSON::MaybeXS 'JSON';
 use Mojo::JSON ();
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 my $BINARY = JSON::MaybeXS->new(utf8 => 1, allow_nonref => 1,
 	allow_unknown => 1, allow_blessed => 1, convert_blessed => 1);
@@ -15,9 +15,13 @@ my $TEXT = JSON::MaybeXS->new(utf8 => 0, allow_nonref => 1,
 my $TRUE = JSON->true;
 my $FALSE = JSON->false;
 
-if (JSON eq 'Cpanel::JSON::XS' && $Cpanel::JSON::XS::VERSION >= 3.0112) {
-	$BINARY->stringify_infnan;
-	$TEXT->stringify_infnan;
+{
+	local $@;
+	if (JSON eq 'Cpanel::JSON::XS'
+	    and eval { Cpanel::JSON::XS->VERSION('3.0112'); 1 }) {
+		$BINARY->stringify_infnan;
+		$TEXT->stringify_infnan;
+	}
 }
 
 monkey_patch 'Mojo::JSON', 'encode_json', sub { $BINARY->encode(shift) };
@@ -29,6 +33,8 @@ monkey_patch 'Mojo::JSON', 'from_json', sub { $TEXT->decode(shift) };
 monkey_patch 'Mojo::JSON', 'true',  sub () { $TRUE };
 monkey_patch 'Mojo::JSON', 'false', sub () { $FALSE };
 
+1;
+
 =head1 NAME
 
 Mojo::JSON::MaybeXS - use JSON::MaybeXS as the JSON encoder for Mojolicious
@@ -38,19 +44,18 @@ Mojo::JSON::MaybeXS - use JSON::MaybeXS as the JSON encoder for Mojolicious
  use Mojo::JSON::MaybeXS;
  use Mojo::JSON qw/encode_json decode_json true false/;
  
- use Mojo::JSON::MaybeXS;
- use Mojolicious::Lite;
+ # Preload for scripts using Mojo::JSON
+ $ perl -MMojo::JSON::MaybeXS $(which morbo) myapp.pl
  
- package My::Mojo::App;
- use Mojo::JSON::MaybeXS;
- use Mojo::Base 'Mojolicious';
+ # Must be set in environment for hypnotoad
+ $ PERL5OPT=-MMojo::JSON::MaybeXS hypnotoad myapp.pl
 
 =head1 DESCRIPTION
 
-L<Mojo::JSON::MaybeXS> is a monkey-patch module for using L<JSON::MaybeXS> in
-place of L<Mojo::JSON> in a L<Mojolicious> application, or in a standalone
-capacity. It must be loaded before L<Mojo::JSON> so the new functions will be
-properly exported.
+L<Mojo::JSON::MaybeXS> is a monkey-patch module for using L<JSON::MaybeXS> as
+the JSON encoder for a L<Mojolicious> application, or anything else using
+L<Mojo::JSON>. It must be loaded before L<Mojo::JSON> so the new functions will
+be properly exported.
 
 =head1 CAVEATS
 
@@ -153,7 +158,7 @@ Sebastian Riedel, author of L<Mojolicious>, for basic implementation.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015, Dan Book.
+Copyright 2014, Dan Book.
 
 This library is free software; you may redistribute it and/or modify it under
 the terms of the Artistic License version 2.0.
@@ -161,7 +166,3 @@ the terms of the Artistic License version 2.0.
 =head1 SEE ALSO
 
 L<Mojo::JSON>, L<JSON::MaybeXS>, L<Cpanel::JSON::XS>, L<JSON::XS>, L<JSON::PP>
-
-=cut
-
-1;
